# beep

A Python module to generate sounds

## Installation

### From PyPI

```sh
pip3 install python-beep
```

### From GitHub

```sh
pip3 install git+https://github.com/donno2048/beep
```

## Usage

```py
from beep import beep
frequency = 327
duration = 1000
beep(frequency, duration) # duration in ms, frequency in Hz
```
